.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self
    details

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    api

.. toctree::
    :caption: Tutorials

    Adafruit Ultimate GPS <https://learn.adafruit.com/adafruit-ultimate-gps>
    Adafruit Ultimate GPS featherwing <https://learn.adafruit.com/adafruit-ultimate-gps-featherwing>
    Adafruit Mini GPS module <https://learn.adafruit.com/adafruit-mini-gps-pa1010d-module>
    GPS Tour Guide <https://learn.adafruit.com/gps-tour-guide>

.. toctree::
    :caption: Related Products

    Adafruit Ultimate GPS Breakout <https://www.adafruit.com/product/746>
    Adafruit Ultimate GPS FeatherWing <https://www.adafruit.com/product/3133>
    Adafruit Mini GPS module <https://www.adafruit.com/product/4415>

.. toctree::
    :caption: Other Links

    Download <https://github.com/adafruit/Adafruit_CircuitPython_GPS/releases/latest>
    CircuitPython Reference Documentation <https://circuitpython.readthedocs.io>
    CircuitPython Support Forum <https://forums.adafruit.com/viewforum.php?f=60>
    Discord Chat <https://adafru.it/discord>
    Adafruit Learning System <https://learn.adafruit.com>
    Adafruit Blog <https://blog.adafruit.com>
    Adafruit Store <https://www.adafruit.com>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
